** The script replicates figures 2 and 3 from Moen, et al. (2019) "Buying first or selling first in housing markets"

clear

** Figure 2(a)------------------------------------------------------------------

use buy_first_frac_sale_dates_annual.dta

merge 1:1 year using copenhagen_price_index_transactions
drop _merge

sort year 



twoway (line frac_buy_first year if year>1992 & year<2009, yaxis(1) clwidth(thick) lpattern(solid) lcolor(gs2)) ///
	(line price_index_single_family year if year>1992 & year<2009, yaxis(2) clwidth(thick) lpattern(solid) lcolor(gs8)), ///
	xti("year") xlabel(1993[3]2008) yti("fraction", axis(1)) yti("price index", axis(2)) ///
	legend(lab(1 "buy first owners (fraction)") lab(2 "price index (Copenhagen)")) graphregion(fcolor(white))

**------------------------------------------------------------------------------

** Figure 2(b)------------------------------------------------------------------
clear
use buy_first_frac_takeover_dates_annual.dta

merge 1:1 year using copenhagen_price_index_transactions
drop _merge
sort year 


twoway (line frac_buy_first year if year>1992 & year<2009, yaxis(1) clwidth(thick) lpattern(solid) lcolor(gs2)) ///
	(line price_index_single_family year if year>1992 & year<2009, yaxis(2) clwidth(thick) lpattern(solid) lcolor(gs8)), ///
	xti("year") xlabel(1993[3]2008) yti("fraction", axis(1)) yti("price index", axis(2)) ///
	legend(lab(1 "buy first owners (fraction)") lab(2 "price index (Copenhagen)")) graphregion(fcolor(white))

**------------------------------------------------------------------------------

** Figure 3 --------------------------------------------------------------------
clear
use copenhagen_housing_and_buy_sell_data_quarterly_2004_2008.dta

twoway (line logTOMHousesDevs qtr, yaxis(1) clwidth(thick) lpattern(solid) lcolor(gs2)) ///
 (line logForSaleHousesDevs qtr, yaxis(1) clwidth(thick) lpattern(solid) lcolor(gs6)) ///
 (line logTransactionsTotDevs qtr, yaxis(1) clwidth(thick) lpattern(solid) lcolor(gs10)) ///
 (line logPriceIndexDevs qtr, yaxis(1) clwidth(thick) lpattern(dot) lcolor(gs2)) ///
 (line frac_buy_first qtr, yaxis(2) clwidth(thick) lpattern(dash) lcolor(gs2)), xti("year") ///
 xlabel(176[4]195) yti("log deviations", axis(1)) yti("fraction", axis(2)) legend(lab(1 "Time-on-market") ///
 lab(2 "For-sale inventory") lab(3 "Transactions") lab(4 "House price index") lab(5 "Buy-first owners (fraction)")) graphregion(fcolor(white))

 
**------------------------------------------------------------------------------ 

** Column 1 of Table xxx: log-changes between 2006Q3 and 2008Q3
local TOM_dev = round((logTOMHousesDevs[19]-logTOMHousesDevs[11]), .01)
local ForSale_dev = round((logForSaleHousesDevs[19]-logForSaleHousesDevs[11]), .01)
local Trans_dev = round((logTransactionsTotDevs[19]-logTransactionsTotDevs[11]), .01)
*local price_dev = round((logPriceIndexDevs[19]-logPriceIndexDevs[11]), .01)
local buy_first_dev = round((frac_buy_first[19]-frac_buy_first[11]), .01)

di "Fraction Buy-first owners (change): `buy_first_dev'" 
di "Time-on-market (log deviation): `TOM_dev'" 
di "For-sale inventory (log deviation): `ForSale_dev'" 
di "Transactions (log deviation): `Trans_dev'" 
*di "House price index (log deviation): `price_dev'"
